import React, { Component } from 'react';
import {
    StyleSheet,
    View,
    ActivityIndicator,
} from 'react-native';


import Login from './Login';
import AppContainer from './AppContainer';
import authService from './AuthService';

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#F5FCFF',
    },
});

class App extends Component {
    constructor(props) {
        super(props);

        this.onLogin = this.onLogin.bind(this);
        this.onLogout = this.onLogout.bind(this);
        this.componentDidMount = this.componentDidMount.bind(this);

        this.state = {
            isLoggedIn: false,
            checkingAuth: true,
        };
    }

    componentDidMount() {
        authService.getAuthInfo((err, authInfo) => {
            this.setState({
                checkingAuth: false,
                isLoggedIn: authInfo.username != null,
            });
            console.log(authInfo);
        });
    }

    onLogin() {
        this.setState({ isLoggedIn: true });
    }

    onLogout() {
        this.setState({ isLoggedIn: false });
    }

    render() {
        if (this.state.checkingAuth) {
            return (
                <View style={styles.container}>
                    <ActivityIndicator
                        animating
                        size="large"
                        style={styles.loader} />
                </View>
            );
        }

        if (this.state.isLoggedIn) {
            return (
                <AppContainer onLogout={this.onLogout.bind(this) } />
            );
        }
        return (
            <Login onLogin={this.onLogin.bind(this) } />
        );
    }
}

module.exports = App;
