import { AsyncStorage } from 'react-native';

const tokenKey = 'token';
const userKey = 'user';

class AuthService {
    getAuthInfo(callback) {
        AsyncStorage.multiGet([tokenKey, userKey], (err, val) => {
            if (err) {
                return callback(err);
            }
            if (!val) {
                return callback();
            }

            const authInfo = {
                header: {
                    Authorization: `Bearer ${val[0][1]}`,
                },
                username: val[1][1],
            };

            return callback(null, authInfo);
        });
    }

    logout() {
        AsyncStorage.multiRemove([tokenKey, userKey]);
    }

    loginOAuth(credentials, callback) {
        const loginDetails = {
            grant_type: 'password',
            username: credentials.username,
            password: credentials.password,
        };

        let formBody = [];

        Object.keys(loginDetails).forEach((property, index) => {
            if ({}.hasOwnProperty.call(loginDetails, property)) {
                const encodedKey = encodeURIComponent(property);
                const encodedValue = encodeURIComponent(loginDetails[property]);
                formBody.push(`${encodedKey}=${encodedValue}`);
            }
        });

        formBody = formBody.join('&');

        const uri = 'https://contacts.akaver.com/Token';

        fetch(uri, {
            method: 'POST',
            headers: {
                Accept: 'application/json',
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: formBody,
        })
            .then((response) => {
                if (response.status >= 200 && response.status <= 299) {
                    return response;
                }
                console.log(response);
                throw { // should be Error object or its derivative
                    badCredentials: response.status === 400,
                    unknownError: response.status !== 400,
                    statusCode: response.status,
                };
            })
            .then((response) => response.json())
            .then((results) => {
                AsyncStorage.multiSet([
                    [tokenKey, results.access_token],
                    [userKey, results.userName],
                ], (err) => {
                    if (err) {
                        throw err;
                    }
                    return callback({ success: true });
                });
            })
            .catch((error) => callback(error));
    }
}

// new it up immediately
module.exports = new AuthService();
