import React, { Component } from 'react';
import {
    StyleSheet,
    Text,
    View,
    ListView,
    ActivityIndicator,
    Image,
} from 'react-native';
import authService from './AuthService';

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'flex-start',
        marginTop: 60,
    },
    containerActivityIdicator: {
        flex: 1,
        justifyContent: 'center',
    },
    row: {
        flex: 1,
        flexDirection: 'row',
        padding: 20,
        alignItems: 'center',
        borderColor: '#D7D7D7',
        borderBottomWidth: 1,
    },
    rowImage: {
        height: 36,
        width: 36,
    },
    rowInnerView: {
        paddingLeft: 20,
    },
    rowText: {
    },
});

class ContactTypes extends Component {

    constructor(props) {
        super(props);
        const ds = new ListView.DataSource({
            rowHasChanged: (r1, r2) => r1 !== r2,
        });

        this.state = {
            dataSource: ds,
            showProgress: true,
        };
    }

    componentDidMount() {
        this.fetchData();
    }

    fetchData() {
        authService.getAuthInfo((err, authInfo) => {
            const url = 'https://contacts.akaver.com/api/ContactTypes';
            fetch(url, {
                headers: authInfo.header,
            })
                .then((response) => response.json())
                .then((responseData) => {
                    this.setState({
                        dataSource: this.state.dataSource.cloneWithRows(responseData),
                        showProgress: false,
                    });
                })
                .done();
        });
    }

    renderRow(rowData) {
        return (
            <View style={styles.row}>
                <Image
                    source={ { uri: rowData.imageUri } }
                    style={styles.rowImage}/>
                <View style={styles.rowInnerView}>
                    <Text style={styles.rowText}>
                        {rowData.contactTypeName}
                    </Text>
                </View>
            </View>
        );
    }

    render() {
        if (this.state.showProgress) {
            return (
                <View style={styles.containerActivityIdicator}>
                    <ActivityIndicator
                        animating
                        size="large"/>
                </View>
            );
        }
        return (
            <View style={styles.container}>
                <ListView
                    dataSource={this.state.dataSource}
                    renderRow={this.renderRow.bind(this) }/>
            </View>
        );
    }
}

ContactTypes.propTypes = {
};

module.exports = ContactTypes;
