import React, { Component } from 'react';
import {
    Platform,
    Text,
    View,
    ListView,
    StyleSheet,
    ActivityIndicator,
    Image,
    TouchableHighlight,
} from 'react-native';
import authService from './AuthService';
import PersonDetails from './PersonDetails';

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'flex-start',
        marginTop: 60,
    },
    containerActivityIdicator: {
        flex: 1,
        justifyContent: 'center',
    },
    row: {
        flex: 1,
        flexDirection: 'row',
        padding: 20,
        alignItems: 'center',
        borderColor: '#D7D7D7',
        borderBottomWidth: 1,
    },
    rowImage: {
        height: 36,
        width: 36,
        borderRadius: 9,
    },
    rowInnerView: {
        paddingLeft: 20,
    },
    rowText: {
    },
});

class Persons extends Component {

    constructor(props) {
        super(props);
        const ds = new ListView.DataSource({
            rowHasChanged: (r1, r2) => r1 !== r2,
        });

        this.pressRow = this.pressRow.bind(this);

        this.state = {
            dataSource: ds,
            showProgress: true,
        };
    }

    componentDidMount() {
        this.fetchData();
    }

    fetchData() {
        authService.getAuthInfo((err, authInfo) => {
            const url = 'https://contacts.akaver.com/api/Persons';
            fetch(url, {
                headers: authInfo.header,
            })
                .then((response) => response.json())
                .then((responseData) => {
                    this.setState({
                        dataSource: this.state.dataSource.cloneWithRows(responseData),
                        showProgress: false,
                    });
                });
        });
    }

    pressRow(rowData) {
        if (Platform.OS === 'ios') {
            this.props.navigator.push({
                title: 'Person Details',
                component: PersonDetails,
                passProps: {
                    personId: rowData.personId,
                },
            });
        }
        // TODO: Android view
    }

    renderRow(rowData) {
        return (
            <TouchableHighlight
                onPress={() => this.pressRow(rowData) }
                underlayColor="#ddd">
                <View style={styles.row}>
                    <Image
                        source={ { uri: rowData.imageUri } }
                        style={styles.rowImage}/>
                    <View style={styles.rowInnerView}>
                        <Text style={styles.rowText}>
                            {rowData.firstname} {rowData.lastname}
                        </Text>
                    </View>
                </View>
            </TouchableHighlight>
        );
    }

    render() {
        if (this.state.showProgress) {
            return (
                <View style={styles.containerActivityIdicator}>
                    <ActivityIndicator
                        animating
                        size="large"/>
                </View>
            );
        }
        return (
            <View style={styles.container}>
                <ListView
                    dataSource={this.state.dataSource}
                    renderRow={this.renderRow.bind(this) }/>
            </View>
        );
    }
}

Persons.propTypes = {
    navigator: React.PropTypes.object, // eslint-disable-line react/forbid-prop-types
};

module.exports = Persons;
